@@ -146,14 +146,19 @@ ews_data_cache_get (CamelDataCache *cdc,
                     GError **error)
 {
 	GChecksum *sha = g_checksum_new (G_CHECKSUM_SHA256);
-	CamelStream *ret;
+	CamelStream *stream = NULL;
+	GIOStream *base_stream;
 
 	g_checksum_update (sha, (guchar *) key, strlen (key));
-	ret = camel_data_cache_get (
+	base_stream = camel_data_cache_get (
 		cdc, path, g_checksum_get_string (sha), error);
+	if (base_stream != NULL) {
+		stream = camel_stream_new (base_stream);
+		g_object_unref (base_stream);
+	}
 	g_checksum_free (sha);
 
-	return ret;
+	return stream;
 }
 
 static gchar *
@@ -194,7 +199,10 @@ camel_ews_folder_get_message_from_cache (CamelEwsFolder *ews_folder,
 			gchar *new_fname = ews_data_cache_get_filename (
 				ews_folder->cache,
 				"cur", uid, error);
-			g_rename (old_fname, new_fname);
+			if (g_rename (old_fname, new_fname) == -1) {
+				g_warning ("%s: Failed to rename '%s' to '%s': %s", G_STRFUNC,
+					   old_fname, new_fname, g_strerror (errno));
+			}
 			g_free (new_fname);
 			stream = ews_data_cache_get (ews_folder->cache, "cur", uid, error);
 		}
@@ -360,7 +368,10 @@ ews_update_mgtrequest_mime_calendar_itemid (const gchar *mime_fname,
 			goto exit_save;
 		if (camel_stream_close (newstream, NULL, error) == -1)
 			goto exit_save;
-		g_remove (mime_fname);
+		if (g_remove (mime_fname) == -1) {
+			g_warning ("%s: Failed to remove file '%s': %s",
+				   G_STRFUNC, mime_fname, g_strerror (errno));
+		}
 		success = TRUE;
  exit_save:
 		if (fd != -1)
@@ -396,7 +407,6 @@ camel_ews_folder_get_message (CamelFolder *folder,
 	CamelEwsStore *ews_store;
 	const gchar *mime_content;
 	CamelMimeMessage *message = NULL;
-	CamelStream *tmp_stream = NULL;
 	GSList *ids = NULL, *items = NULL;
 	gchar *mime_dir;
 	gchar *cache_file;
@@ -566,9 +576,6 @@ exit:
 		g_slist_free (items);
 	}
 
-	if (tmp_stream)
-		g_object_unref (tmp_stream);
-
 	if (mime_fname_new)
 		g_free (mime_fname_new);
 	g_object_unref (cnc);
