@@ -205,6 +205,26 @@ typedef struct {
 	gsize len;
 } EwsPhotoAttachmentInfo;
 
+typedef enum {
+	E_EWS_NOTIFICATION_EVENT_COPIED = 0,
+	E_EWS_NOTIFICATION_EVENT_CREATED,
+	E_EWS_NOTIFICATION_EVENT_DELETED,
+	E_EWS_NOTIFICATION_EVENT_MODIFIED,
+	E_EWS_NOTIFICATION_EVENT_MOVED,
+	E_EWS_NOTIFICATION_EVENT_STATUS,
+} EEwsNotificationEventType;
+
+typedef struct {
+	EEwsNotificationEventType type;
+	gboolean is_item;
+	gchar *folder_id;
+	gchar *old_folder_id;
+} EEwsNotificationEvent;
+
+EEwsNotificationEvent *
+		e_ews_notification_event_new	(void);
+void		e_ews_notification_event_free	(EEwsNotificationEvent *event);
+
 void		ews_oal_free			(EwsOAL *oal);
 void		ews_oal_details_free		(EwsOALDetails *details);
 
@@ -224,6 +244,12 @@ void		e_ews_connection_set_password	(EEwsConnection *cnc,
 						 const gchar *password);
 const gchar *	e_ews_connection_get_impersonate_user
 						(EEwsConnection *cnc);
+GProxyResolver *
+		e_ews_connection_ref_proxy_resolver
+						(EEwsConnection *cnc);
+void		e_ews_connection_set_proxy_resolver
+						(EEwsConnection *cnc,
+						 GProxyResolver *proxy_resolver);
 CamelEwsSettings *
 		e_ews_connection_ref_settings	(EEwsConnection *cnc);
 SoupSession *	e_ews_connection_ref_soup_session
@@ -1071,6 +1097,56 @@ gboolean	e_ews_connection_query_auth_methods_sync
 						 GSList **auth_methods,
 						 GCancellable *cancellable,
 						 GError **error);
+void		e_ews_connection_subscribe_folder
+						(EEwsConnection *cnc,
+						 gint pri,
+						 GSList *folders,
+						 GSList *events,
+						 GCancellable *cancellable,
+						 GAsyncReadyCallback callback,
+						 gpointer user_data);
+gboolean	e_ews_connection_subscribe_folder_finish
+						(EEwsConnection *cnc,
+						 GAsyncResult *result,
+						 gchar **subscription_id,
+						 GError **error);
+gboolean	e_ews_connection_subscribe_folder_sync
+						(EEwsConnection *cnc,
+						 gint pri,
+						 GSList *folders,
+						 GSList *events,
+						 gchar **subscription_id,
+						 GCancellable *cancellable,
+						 GError **error);
+void		e_ews_connection_unsubscribe_folder
+						(EEwsConnection *cnc,
+						 gint pri,
+						 const gchar *subscription_id,
+						 GCancellable *cancellable,
+						 GAsyncReadyCallback callback,
+						 gpointer user_data);
+gboolean	e_ews_connection_unsubscribe_folder_finish
+						(EEwsConnection *cnc,
+						 GAsyncResult *result,
+						 GError **error);
+gboolean	e_ews_connection_unsubscribe_folder_sync
+						(EEwsConnection *cnc,
+						 gint pri,
+						 const gchar *subscription_id,
+						 GCancellable *cancellable,
+						 GError **error);
+gboolean	e_ews_connection_enable_notifications_sync
+						(EEwsConnection *cnc,
+						 GSList *folders,
+						 GSList *events,
+						 gchar **subscription_id,
+						 GCancellable *cancellable,
+						 GError **error);
+gboolean	e_ews_connection_disable_notifications_sync
+						(EEwsConnection *cnc,
+						 const gchar *subscription_id,
+						 GCancellable *cancellable,
+						 GError **error);
 
 G_END_DECLS
 
